@@ -12,10 +12,10 @@ from mcdbot.config import Config
 from mcdbot.discordcontext import DiscordContext
 from mcdbot.logging_integration import integrate_logging
 
-
 import asyncio
 from datetime import datetime
 import discord
+from discord.ext import tasks
 # import logging
 from loguru import logger
 import signal
@@ -35,7 +35,7 @@ class Mcdbot(discord.Client):
         # handler = logging.FileHandler(filename='discord.log', encoding='utf-8', mode='w')
         # handler.setFormatter(logging.Formatter('%(asctime)s:%(levelname)s:%(name)s: %(message)s'))
         # self.discord_logger.addHandler(handler)
-
+        logger.remove()
         self.logger_id = logger.add(config.mcdbot_log,
                                     level="DEBUG" if config.debug else "WARNING",
                                     backtrace=True,
@@ -46,10 +46,12 @@ class Mcdbot(discord.Client):
         from mcdbot.mojang_api import MojangApi
         from mcdbot.rcon import Rcon
         from mcdbot.redis import Redis
+        from mcdbot.whitelist import Whitelist
 
         self.redis = Redis()
         self.rcon = Rcon()
         self.mojang_api = MojangApi()
+        self.whitelist = Whitelist(self)
 
         intents = discord.Intents.none()
         intents.messages = True
@@ -73,11 +75,19 @@ class Mcdbot(discord.Client):
         async def runner():
             nonlocal self, token
             try:
-                await self.redis.start()
-                await self.rcon.start()
-                await self.mojang_api.start()
+                logger.info("Starting the main loop...")
+                try:
+                    await self.redis.start()
+                    await self.rcon.start()
+                    await self.mojang_api.start()
+                except ConnectionError as ce:
+                    logger.error(f"Connection error => {ce}")
                 await self.start(token)
+            except Exception as e:
+                logger.exception("TEST", e)
+                raise e
             finally:
+                logger.warning("Shutting down...")
                 await self.mojang_api.stop()
                 await self.rcon.stop()
                 await self.redis.stop()
@@ -108,6 +118,14 @@ class Mcdbot(discord.Client):
     def main_guild(self):
         return self.get_guild(global_config.main_guild_id)
 
+    @tasks.loop(minutes=global_config.chore_loop_time)
+    async def do_chores(self):
+        pass
+
+    @do_chores.before_loop
+    async def wait_before_doing_chores(self):
+        logger.info('Waiting for the bot to connect before doing chores...')
+
     async def on_error(self, event_method, *args, **kwargs):
         now = datetime.now().isoformat()
         logger.critical("Uncaught exception!!! Trying to send a message to the discord main channel...")
@@ -119,13 +137,13 @@ class Mcdbot(discord.Client):
             main_channel = self.get_channel(global_config.main_channel_id)
             await main_channel.send(
                 f"{admin_role_mention} "
-                f"[CRITICAL] AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA!!! "
+                f"[CRITICAL] Uncaught exception!!! "
                 f"TIME = {now}"
             )
         except Exception as e:
             logger.error("It seems that I can't send the message noticing of the exception. Hmm, that's bad...")
             raise e
-        raise
+        # raise
 
     async def on_message(self, message):
         try:
